@@ -132,6 +132,8 @@ cvar_t	*cl_vwep;
 cvar_t  *background_music;
 cvar_t	*background_music_vol;
 
+cvar_t	*cl_show_active_servers_only;
+
 cvar_t	*scriptsloaded;
 
 //master server
@@ -172,6 +174,7 @@ extern	cvar_t *allow_download_players;
 extern	cvar_t *allow_download_models;
 extern	cvar_t *allow_download_sounds;
 extern	cvar_t *allow_download_maps;
+extern	cvar_t *auto_installmap;
 
 #if defined WIN32_VARIANT
 extern	char map_music[MAX_PATH];
@@ -648,7 +651,9 @@ void CL_Connect_f (void)
 	strncpy (cls.servername, server, sizeof(cls.servername)-1);
 	cls.connect_time = -99999;	// CL_CheckForResend() will fire immediately
 
-	STATS_RequestVerification();
+	if (STATS_ENABLED) {
+		STATS_RequestVerification();
+	}
 }
 
 
@@ -1502,9 +1507,34 @@ void CL_RequestNextDownload (void)
 	if (precache_check == CS_MODELS) // confirm map
 	{
 		precache_check = CS_MODELS+2; // 0 isn't used
-		if (allow_download_maps->integer)
-			if (!CL_CheckOrDownloadFile(cl.configstrings[CS_MODELS+1]))
+		if (allow_download_maps->integer) {
+			
+			if (auto_installmap->integer && 
+				cl.configstrings[CS_MODELS + 1][0] == 'm' &&
+				cl.configstrings[CS_MODELS + 1][1] == 'a' &&
+				cl.configstrings[CS_MODELS + 1][2] == 'p' &&
+				cl.configstrings[CS_MODELS + 1][3] == 's' &&
+				cl.configstrings[CS_MODELS + 1][4] == '/') {
+				
+				char mapname[256];
+				
+				// Strip "maps/"
+				strcpy(mapname, cl.configstrings[CS_MODELS + 1] + 5);
+
+				if (strstr(mapname, ".bsp")) {
+					// Strip ".bsp"
+					mapname[strlen(mapname) - 4] = 0;
+
+					if (CL_InstallMapOrModel(INSTALL_TYPE_MAP, mapname) == INSTALL_MAP_RESULT_DOWNLOAD_INITIATED) {
+						return;
+					};
+				}
+			}
+
+			if (!CL_CheckOrDownloadFile(cl.configstrings[CS_MODELS+1])) {
 				return; // started a download
+			}
+		}
 	}
 	
 redoSkins:
@@ -1932,6 +1962,32 @@ void CL_Precache_f (void)
 	CL_RequestNextDownload();
 }
 
+/*
+In case equal to the old default, then change to the new default.
+Only usable for string cvars for now.
+*/
+void CL_RepairStringCvarIfDefault(cvar_t *cvar, char *oldDefault, char *newDefault)
+{
+	if (!Q_strcasecmp(cvar->string, oldDefault)) {
+		Com_Printf("%s changed from %s to %s\n", cvar->name, cvar->string, newDefault);
+		Cvar_Set(cvar->name, newDefault);
+		strcpy(cvar->string, newDefault);
+	}
+}
+
+/*
+In case not equal to the new default, then change to the new default.
+Only usable for string cvars for now.
+*/
+void CL_RepairStringCvar(cvar_t *cvar, char *newDefault)
+{
+	if (Q_strcasecmp(cvar->string, newDefault)) {
+		Com_Printf("%s changed from %s to %s\n", cvar->name, cvar->string, newDefault);
+		Cvar_Set(cvar->name, newDefault);
+		strcpy(cvar->string, newDefault);
+	}
+}
+
 /*
 =================
 CL_InitLocal
@@ -1976,7 +2032,7 @@ void CL_InitLocal (void)
 	Cvar_Describe (cl_noskins, "for all players to be shown with the same skin.");
 	cl_autoskins = Cvar_Get ("cl_autoskins", "0", CVARDOC_BOOL);
 	cl_predict = Cvar_Get ("cl_predict", "1", CVARDOC_BOOL);
-	cl_maxfps = Cvar_Get ("cl_maxfps", "120", CVAR_ARCHIVE | CVARDOC_INT);
+	cl_maxfps = Cvar_Get ("cl_maxfps", "60", CVAR_ARCHIVE | CVARDOC_INT);
 	Cvar_Describe (cl_maxfps, "limit the frames drawn per second using a busy-wait loop.");
 	cl_showPlayerNames = Cvar_Get ("cl_showplayernames", "0", CVAR_ARCHIVE | CVARDOC_INT);
 	Cvar_Describe (cl_showPlayerNames, "0 means no nametags, 1 means show one nametag in the center of the screen, 2 means show a nametag over each player.");
@@ -1995,9 +2051,9 @@ void CL_InitLocal (void)
 	cl_flicker = Cvar_Get ("cl_flicker", "1", CVAR_ARCHIVE | CVARDOC_BOOL);
 	Cvar_Describe (cl_flicker, "enable flickering world lighting.");
 
-	cl_paindist = Cvar_Get ("cl_paindist", "1", CVAR_ARCHIVE);
+	cl_paindist = Cvar_Get ("cl_paindist", "0", CVAR_ARCHIVE);
 	Cvar_Describe (cl_paindist, "distort the screen when you take damage.");
-	cl_explosiondist = Cvar_Get ("cl_explosiondist", "1", CVAR_ARCHIVE);
+	cl_explosiondist = Cvar_Get ("cl_explosiondist", "0", CVAR_ARCHIVE);
 	Cvar_Describe (cl_explosiondist, "distort the screen for explosions.");
 	cl_raindist = Cvar_Get ("cl_raindist", "1", CVAR_ARCHIVE);
 	Cvar_Describe (cl_raindist, "rain running down your visor.");
@@ -2038,6 +2094,9 @@ void CL_InitLocal (void)
 	rcon_client_password = Cvar_Get ("rcon_password", "", CVARDOC_STR);
 	rcon_address = Cvar_Get ("rcon_address", "", CVARDOC_STR);
 	
+	cl_show_active_servers_only = Cvar_Get("cl_show_active_servers_only", "0", CVARDOC_BOOL);
+	Cvar_Describe (cl_show_active_servers_only, "Only show active servers in the server list. Will not be remembered when quitting.");
+
 	cl_test = Cvar_Get ("cl_test", "0", CVAR_ARCHIVE);
 
 	//
@@ -2066,21 +2125,28 @@ void CL_InitLocal (void)
 
 	cl_vwep = Cvar_Get ("cl_vwep", "1", CVAR_ARCHIVE | CVARDOC_BOOL);
 
-	cl_master = Cvar_Get ("cl_master", "master.corservers.com", CVAR_ARCHIVE | CVARDOC_STR);
-	cl_master2 = Cvar_Get ("cl_master2", "master2.corservers.com", CVAR_ARCHIVE | CVARDOC_STR);
+	cl_master = Cvar_Get ("cl_master", DEFAULT_MASTER_1, CVAR_ARCHIVE | CVARDOC_STR);
+	cl_master2 = Cvar_Get ("cl_master2", DEFAULT_MASTER_2, CVAR_ARCHIVE | CVARDOC_STR);	
+	if (USE_ALIENARENA_ORG) {
+		CL_RepairStringCvar(cl_master, DEFAULT_MASTER_1);
+		CL_RepairStringCvar(cl_master2, DEFAULT_MASTER_2);
+	}
 
-	//custom huds
+	// custom huds
 	cl_hudimage1 = Cvar_Get("cl_hudimage1", "pics/i_health.tga", CVAR_ARCHIVE | CVARDOC_STR);
 	cl_hudimage2 = Cvar_Get("cl_hudimage2", "pics/i_score.tga", CVAR_ARCHIVE | CVARDOC_STR);
 	cl_hudimage3 = Cvar_Get("cl_hudimage3", "pics/i_ammo.tga", CVAR_ARCHIVE | CVARDOC_STR);
 
-	//stats server
-	cl_stats_server = Cvar_Get("cl_stats_server", "https://martianbackup.com", CVAR_ARCHIVE | CVARDOC_STR);
+	// stats server
+	cl_stats_server = Cvar_Get("cl_stats_server", DEFAULT_STATS_URL, CVAR_ARCHIVE | CVARDOC_STR);
 
-	//update checker
-	cl_latest_game_version_url = Cvar_Get("cl_latest_game_version_server", "https://martianbackup.com/version/crx_version", CVAR_ARCHIVE | CVARDOC_STR);
+	// update checker
+	cl_latest_game_version_url = Cvar_Get("cl_latest_game_version_server", DEFAULT_VERSION_CHECK_URL, CVAR_ARCHIVE | CVARDOC_STR);	
+	if (USE_ALIENARENA_ORG) {
+		CL_RepairStringCvar(cl_latest_game_version_url, VERSION_CHECK_ALIENARENA_ORG_URL);
+	}
 
-	//throwaway cvars
+	// throwaway cvars
 	Cvar_Get("g_dm_lights", "1", CVAR_ARCHIVE | CVAR_GAMEINFO | CVARDOC_BOOL); //mark this as archived even if game code doesn't run.
 
 	//
@@ -2112,6 +2178,8 @@ void CL_InitLocal (void)
 
 	Cmd_AddCommand ("download", CL_Download_f);
 	Cmd_AddCommand ("downloadhttp", CL_Download_f);
+	Cmd_AddCommand ("installmap", CL_InstallMap);
+	Cmd_AddCommand ("installmodel", CL_InstallModel);
 
 	Cmd_AddCommand ("irc_connect", CL_InitIRC);
 	Cmd_AddCommand ("irc_quit", CL_IRCInitiateShutdown);
@@ -2864,7 +2932,9 @@ void CL_Shutdown(void)
 	}
 	isdown = true;
 
-	STATS_Logout();
+	if (STATS_ENABLED) {
+		STATS_Logout();
+	}
 
 	STATS_ST_Write();
 
