@@ -24,6 +24,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 
 #include "client.h"
+#include "qcommon/qcommon.h"
+#include "minizip/unzip.h"
 
 char *svc_strings[256] =
 {
@@ -54,6 +56,10 @@ char *svc_strings[256] =
 
 static size_t szr; // just for unused result warnings
 
+extern	cvar_t *allow_overwrite_maps;
+
+qboolean CL_ExtractFiles(char *zipFilename);
+
 /*
 ==============
 Q_strncpyz
@@ -86,15 +92,39 @@ void CL_DownloadComplete (void)
 	int		r;
 	char	oldn[MAX_OSPATH];
 	char	newn[MAX_OSPATH];
-		
+
+	if (cls.downloadmappack) {
+		// Save map/model packs in folder "arena/downloads".
+		// cls.downloadname has to be excluding "downloads/" else it searches for the wrong location to download from.
+		// cls.downloadtempname already contains "downloads/".
+		Com_sprintf(cls.downloadname, sizeof(cls.downloadname), "downloads/%s", cls.downloadname);
+	}	
+
 	// rename the temp file to it's final name
 	CL_DownloadFileName(oldn, sizeof(oldn), cls.downloadtempname);
 	CL_DownloadFileName(newn, sizeof(newn), cls.downloadname);
+	
 	r = rename (oldn, newn);
-	if (r)
-		Com_Printf ("failed to rename.\n");
-	else
-		Com_Printf("Download complete: %s\n", cls.downloadname );
+	if (r) {
+		// File already exists?
+		Com_Printf("failed to rename %s to %s.\n", cls.downloadtempname, cls.downloadname);
+	}
+	else {
+		Com_Printf("Download complete: %s\n", cls.downloadname);
+	}
+
+	if (cls.downloadmappack) {
+		if (CL_ExtractFiles(cls.downloadname)) {
+			// Clear current map name so CM_LoadBSP() doesn't give a map difference error
+			map_name[0] = 0;
+			Com_Printf("Installed %s.\n", cls.downloadname);
+		}
+		else {
+			Com_Printf("Couldn't install %s.\n", cls.downloadname);
+		}
+
+		cls.downloadmappack = 0;
+	}
 }
 
 /*
@@ -301,6 +331,274 @@ void	CL_Download_f (void)
 	}
 }
 
+/*
+** If the path in filename starts with "arena/", then it returns a copy of the original string without the "arena/" part.
+*/
+char *RemoveArenaFolderFromPath(char *filename) {
+	// Equal means that it starts with "arena/"
+	if (strstr(filename, "arena/") == filename) {
+		static char newFilename[MAX_OSPATH];
+		strcpy(newFilename, filename + 6);
+		return newFilename;
+	}
+	return filename;
+}
+
+/*
+===============
+CL_ExtractFiles
+
+Extracts downloaded zip containing one or more maps using minizip.
+The zip will be located in the arena/downloads folder. The zip will contain an arena folder and everything else is in there.
+All files will be directly extracted from the read zip file to the place where they belong and the zip file remains in the arena/downloads folder.
+===============
+*/
+
+#define dir_delimiter '/'
+#define READ_SIZE 8192
+
+qboolean CL_ExtractFiles(char *zipFilename)
+{
+	char fullPath[MAX_OSPATH];
+	
+	CL_DownloadFileName(fullPath, sizeof(fullPath), zipFilename);
+
+    // Open the zip file
+    unzFile *zipfile = unzOpen(fullPath);
+    if ( zipfile == NULL )
+    {
+        Com_Printf("Not found: %s\n", fullPath);
+        return false;
+    }
+
+    // Get info about the zip file
+    unz_global_info global_info;
+    if (unzGetGlobalInfo(zipfile, &global_info) != UNZ_OK)
+    {
+        Com_Printf("Could not read file global info.\n");
+        unzClose( zipfile );
+        return false;
+    }
+
+    // Buffer to hold data read from the zip file.
+    char read_buffer[READ_SIZE];
+
+    // Loop to extract all files
+    uLong i;
+    for (i = 0; i < global_info.number_entry; ++i)
+    {
+        // Get info about current file.
+        unz_file_info file_info;
+        char originalFilename[MAX_OSPATH];
+        char filename[MAX_OSPATH];
+        if (unzGetCurrentFileInfo(
+            zipfile,
+            &file_info,
+            originalFilename,
+            MAX_OSPATH,
+            NULL, 0, NULL, 0) != UNZ_OK)
+        {
+            Com_Printf("Could not read file info.\n");
+            unzClose(zipfile);
+            return false;
+        }
+
+		// The zip has the "arena/" folder within the root, so correct for that
+		strcpy(filename, RemoveArenaFolderFromPath(originalFilename));
+
+		CL_DownloadFileName(fullPath, sizeof(fullPath), filename);
+
+        // Check if this entry is a directory or file.
+        const size_t filename_length = strlen(filename);
+        if (filename[filename_length - 1] == dir_delimiter)
+        {
+            // Entry is a directory, so create it.
+			Sys_Mkdir(fullPath);
+        }
+        else if (filename[0] != 0)
+        {
+            // Entry is a file, so extract it.
+            if (unzOpenCurrentFile( zipfile ) != UNZ_OK)
+            {
+                Com_Printf("Could not open file.\n");
+                unzClose( zipfile );
+                return false;
+            }	
+
+            if (!FS_CheckFile(fullPath) || allow_overwrite_maps->integer)
+            {
+				FILE *out = fopen(fullPath, "wb"); // write / binary
+				if (out) {
+					int readResult = UNZ_OK;
+					do    
+					{
+						readResult = unzReadCurrentFile(zipfile, read_buffer, READ_SIZE);
+						if (readResult < 0) // Error
+						{
+							Com_Printf("Error: %d\n", readResult);
+							unzCloseCurrentFile( zipfile );
+							unzClose( zipfile );
+							return false;
+						}
+
+						// Write data to file.
+						if (readResult > 0) // No error
+						{
+							size_t writeResult;
+							writeResult = fwrite(read_buffer, readResult, 1, out);
+						}
+					} while (readResult > 0);
+					
+					fclose(out);
+					
+					Com_Printf("Extracted %s.\n", originalFilename);
+				} else {
+					Com_Printf("Can't open file %s for writing.\n", fullPath);
+				}
+			}
+        }
+
+        unzCloseCurrentFile(zipfile);
+
+        // Go to the next entry listed in the zip file.
+        if ((i + 1) < global_info.number_entry)
+        {
+            if (unzGoToNextFile(zipfile) != UNZ_OK)
+            {
+                Com_Printf("Could not read next file.\n");
+                unzClose(zipfile);
+                return false;
+            }
+        }
+    }
+
+    unzClose(zipfile);
+
+	return true;
+}
+
+/*
+===============
+CL_InstallMapOrModel
+
+From command "installmap" or "installmodel". Request a map/model pack download from alienarena.org in zip format and extract the files.
+filenameArg: map or model name without extension.
+Return values:
+0: map pack doesn't exist and download was initiated
+1: invalid parameters or an error occurred
+2: map pack already exists
+===============
+*/
+int CL_InstallMapOrModel (int type, char *filenameArg)
+{
+	char filename[MAX_OSPATH];
+	char fullPath[MAX_OSPATH];
+	char destinationPath[MAX_OSPATH];
+	qboolean not_enough_args;
+
+	if (!filenameArg || strlen(filenameArg) == 0) {
+		not_enough_args = Cmd_Argc () != 2;
+
+		if (cls.download) {
+			Com_Printf ("Already downloading something.\n");
+		}
+
+		if (not_enough_args || cls.download)
+		{
+			if (type == INSTALL_TYPE_MAP)
+			{
+				Com_Printf ("Usage: installmap <filename> - Download and extract a map pack from alienarena.org.\nSee also cvar allow_overwrite_maps to force a reinstall.\n");
+			}
+			else if (type == INSTALL_TYPE_MODEL)
+			{
+				Com_Printf ("Usage: installmodel <filename> - Download and extract a model pack from alienarena.org.\nSee also cvar allow_overwrite_maps to force a reinstall.\n");
+			}
+			return INSTALL_MAP_RESULT_ERROR;
+		}
+	}
+	
+	if (filenameArg && strlen(filenameArg) > 0) {
+		Com_sprintf(filename, sizeof(filename), "%s", filenameArg);
+	} else {
+		Com_sprintf(filename, sizeof(filename), "%s", Cmd_Argv(1));
+	}
+
+	if (strstr(filename, ".."))
+	{
+		Com_Printf("Refusing to download a path with ..\n");
+		return INSTALL_MAP_RESULT_ERROR;
+	}
+	
+	COM_StripExtension(COM_SkipPath(filename), filename);
+	// cls.downloadname contains only the map name as it will be downloaded from the server: ctf-map.zip
+	// but it will be stored in arena/downloads/ctf-map.zip
+	Com_sprintf(cls.downloadname, sizeof(cls.downloadname), "%s.zip", filename);
+	Com_sprintf(destinationPath, sizeof(destinationPath), "downloads/%s", cls.downloadname);
+	CL_DownloadFileName(fullPath, sizeof(fullPath), destinationPath);
+	
+	if (FS_CheckFile(fullPath)) {
+		if (!allow_overwrite_maps->integer) {
+			if (type == INSTALL_TYPE_MAP)
+			{
+				Com_Printf("Map pack already exists. Set allow_overwrite_maps to 1 to redownload and reinstall.\n");
+			}
+			else if (type == INSTALL_TYPE_MODEL)
+			{
+				Com_Printf("Model pack already exists. Set allow_overwrite_maps to 1 to redownload and reinstall.\n");
+			}
+			cls.downloadname[0] = 0;
+			return INSTALL_MAP_RESULT_ALREADY_EXISTS;
+		}
+		else {
+			// Delete existing zip file
+			remove(fullPath);
+		}
+	}
+
+	// cls.downloadtempname contains "downloads/" from here already
+	Com_sprintf(cls.downloadtempname, sizeof(cls.downloadtempname), "downloads/%s.tmp", filename);
+	cls.downloadfromcommand = true;
+	cls.downloadmappack = type;
+
+	CL_HttpDownloadMapPack(MAPPACK_URL);
+	
+	if (type == INSTALL_TYPE_MAP)
+	{
+		Com_Printf("Map pack download started: %s\n", cls.downloadname);
+	}
+	else if (type == INSTALL_TYPE_MODEL)
+	{
+		Com_Printf("Model pack download started: %s\n", cls.downloadname);
+	}
+
+	// The extracting part will be done in CL_ExtractFiles(), called from CL_DownloadComplete()
+	return INSTALL_MAP_RESULT_DOWNLOAD_INITIATED;
+}
+
+/*
+===============
+CL_InstallMap
+
+From command "installmap". Request a map pack download from alienarena.org in zip format and extract the files.
+===============
+*/
+void CL_InstallMap(void)
+{
+	CL_InstallMapOrModel(INSTALL_TYPE_MAP, NULL);
+}
+
+/*
+===============
+CL_InstallModel
+
+From command "installmodel". Request a model pack download from alienarena.org in zip format and extract the files.
+===============
+*/
+void CL_InstallModel(void)
+{
+	CL_InstallMapOrModel(INSTALL_TYPE_MODEL, NULL);
+}
+
 /*
 ======================
 CL_RegisterSounds
@@ -340,6 +638,12 @@ static qboolean is_jpg()
 	return  !Q_strncasecmp( ".jpg", &cls.downloadname[exti], 4 );
 }
 
+static qboolean is_zip()
+{
+	size_t exti = strlen(cls.downloadname) - 4;
+	return  !Q_strncasecmp( ".zip", &cls.downloadname[exti], 4 );
+}
+
 /*
 =====================
 CL_ParseDownload
@@ -369,6 +673,21 @@ void CL_ParseDownload (void)
 			// Failed download was not a .jpg.
 			Com_Printf ("Server does not have file %s.\n", cls.downloadname);
 
+			if (is_zip() && cls.downloadmappack == INSTALL_TYPE_MAP) {
+				// If this is a non-existing map pack, then continue downloading the old way
+				Com_Printf("Revert to downloading map using sv_downloadurl.\n");
+
+				cls.downloadmappack = 0;
+				Com_sprintf(cls.downloadname, sizeof(cls.downloadname), "maps/%s", cls.downloadname);
+				COM_StripExtension(cls.downloadname, cls.downloadname);				
+				Com_sprintf(cls.downloadtempname, sizeof(cls.downloadtempname), "%s.tmp", cls.downloadname);				
+				strcat(cls.downloadname, ".bsp");
+
+				if (!CL_CheckOrDownloadFile(cls.downloadname)) {
+					return; // started a download
+				}
+			}
+
 			//nuke the temp filename, we don't want that getting left around.
 			cls.downloadtempname[0] = 0;
 			cls.downloadname[0] = 0;
