@@ -459,7 +459,7 @@ void SCR_Sky_f (void)
 		axis[2] = 1;
 	}
 
-	R_SetSky (Cmd_Argv(1), rotate, axis);
+	R_SetSky (Cmd_Argv(1), rotate, axis, true);
 }
 
 //============================================================================
