@@ -265,6 +265,12 @@ typedef struct
 	char		downloadurl[MAX_OSPATH];  // for http downloads
 	qboolean	downloadhttp;
 	qboolean	downloadfromcommand;
+	
+	// 0 = not applicable
+	// 1 = downloading a map pack
+	// 2 = downloading a model pack
+	// see also INSTALL_TYPE_MAP and INSTALL_TYPE_MODEL
+	int			downloadmappack;
 
 // demo recording info must be here, so it isn't cleared on level change
 	qboolean	demorecording;
@@ -341,6 +347,8 @@ extern	cvar_t	*cl_vwep;
 
 extern  cvar_t  *background_music;
 
+extern 	cvar_t	*cl_show_active_servers_only;
+
 extern  cvar_t	*cl_IRC_connect_at_startup;
 extern	cvar_t	*cl_IRC_server;
 extern	cvar_t	*cl_IRC_channel;
@@ -490,6 +498,8 @@ void CL_PingServers_f (void);
 void CL_Snd_Restart_f (void);
 void CL_Precache_f (void);
 void CL_RequestNextDownload (void);
+void CL_RepairStringCvarIfDefault(cvar_t *cvar, char *oldDefault, char *newDefault);
+void CL_RepairStringCvar(cvar_t *cvar, char *newDefault);
 
 //
 // cl_input
@@ -555,6 +565,18 @@ void CL_DownloadFileName (char *dest, int destlen, char *fn);
 void CL_DownloadComplete (void);
 void CL_Download_f (void);
 
+// also used for cls.downloadmappack
+#define INSTALL_TYPE_MAP	1
+#define INSTALL_TYPE_MODEL	2
+
+#define INSTALL_MAP_RESULT_DOWNLOAD_INITIATED	0
+#define INSTALL_MAP_RESULT_ERROR 				1
+#define INSTALL_MAP_RESULT_ALREADY_EXISTS		2
+
+void CL_InstallMap (void);
+void CL_InstallModel (void);
+int CL_InstallMapOrModel (int type, char *filenameArg);
+
 //
 // cl_scrn.c
 //
@@ -597,9 +619,9 @@ void STATS_ST_Write (void);
 // cl_updates.c
 //
 
-void getLatestGameVersion( void );
-qboolean serverIsOutdated (char *server_vstring);
-char* VersionUpdateNotice( void );
+void CL_GetLatestGameVersion( void );
+qboolean CL_ServerIsOutdated (char *server_vstring);
+char* CL_VersionUpdateNotice( void );
 
 
 //
@@ -748,7 +770,9 @@ typedef struct _SERVERDATA {
 	int	 playerRankings[MAX_PLAYERS];
 	char skill[32];
 	int players;
-	char szPlayers[11];
+	int bots;
+	char szPlayers[13];
+	char szPlayersSortvalue[8]; // needed for sorting on the combination of player count and ping
 	int ping;
 	char szPing[6];
 	netadr_t local_server_netadr;
@@ -760,6 +784,8 @@ typedef struct _SERVERDATA {
 
 SERVERDATA connectedserver;
 
+#define PLAYER_NAME_UNIQUE (strcmp (Cvar_VariableString ("name"), "Player") != 0)
+
 void M_Init (void);
 void M_Keydown (int key);
 void M_Draw (void);
@@ -828,6 +854,7 @@ void M_Think_MouseCursor (void);
 void CL_InitHttpDownload(void);
 void CL_HttpDownloadCleanup(void);
 qboolean CL_HttpDownload(void);
+qboolean CL_HttpDownloadMapPack(char *host);
 void CL_HttpDownloadThink(void);
 void CL_ShutdownHttpDownload(void);
 
