@@ -28,6 +28,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define	VERSION		"7.7"
 #endif
 
+// To test the outdated version message:
+// #define	VERSION		"7.71.3"
+
 #define MENU_STATIC_WIDTH	720.0f
 
 #define DEFAULTMODEL		"martianenforcer"
@@ -51,6 +54,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #else
 
+// TODO: remove
+#define BUFFER_DEBUG 1
+
 #if !defined BUILDSTRING
 #define BUILDSTRING "?OS?"
 #endif
@@ -61,10 +67,52 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #endif
 
-// NOTE: the game does *not* depend on these being the same for server and
-// client.
-#define DEFAULT_DOWNLOAD_URL_1 "https://martianbackup.com/sv_downloadurl"
-#define DEFAULT_DOWNLOAD_URL_2 "https://red.planetarena.org/sv_downloadurl"
+// All urls below use http and not https because on windows they are giving problems with libcurl.
+// It results into error "Protocol "https" not supported or disabled in libcurl."
+
+// Enable/disable the old stats
+#define STATS_ENABLED false
+#define DEFAULT_STATS_URL "http://martianbackup.com"
+
+
+// All game operations including IRC
+#define USE_ALIENARENA_ORG true
+#define USE_ALIENARENA_ORG_IRC true
+
+// Obsolete:
+#define VERSION_CHECK_PLANETARENA_URL "http://martianbackup.com/version/crx_version"
+#define VERSION_CHECK_MARTIANBACKUP_URL "http://martianbackup.com/version/crx_version"
+
+#define VERSION_CHECK_ALIENARENA_ORG_URL "http://invader.alienarena.org/version/crx_version"
+#define DEFAULT_VERSION_CHECK_URL (USE_ALIENARENA_ORG ? VERSION_CHECK_ALIENARENA_ORG_URL : VERSION_CHECK_MARTIANBACKUP_URL)
+
+// Obsolete:
+#define IRC_PLANETARENA "irc.planetarena.org"
+#define IRC_HAL_NANOID "hal.nanoid.net"
+
+#define IRC_ALIENARENA_ORG "irc.alienarena.org"
+#define DEFAULT_IRC_SERVER (USE_ALIENARENA_ORG_IRC ? IRC_ALIENARENA_ORG : IRC_HAL_NANOID)
+
+// Obsolete:
+#define DEFAULT_MASTER_COR_1 "master.corservers.com"
+#define DEFAULT_MASTER_COR_2 "master2.corservers.com"
+
+#define DEFAULT_MASTER_1 (USE_ALIENARENA_ORG ? "master.alienarena.org" : DEFAULT_MASTER_COR_1)
+#define DEFAULT_MASTER_2 (USE_ALIENARENA_ORG ? "master2.alienarena.org" : DEFAULT_MASTER_COR_2)
+
+// NOTE: the game does *not* depend on these being the same for server and client.
+#define DEFAULT_DOWNLOAD_URL_1 (USE_ALIENARENA_ORG ? "http://invader.alienarena.org/sv_downloadurl" : "http://martianbackup.com/sv_downloadurl")
+#define DEFAULT_DOWNLOAD_URL_2 (USE_ALIENARENA_ORG ? "http://martianbackup.com/sv_downloadurl" : "http://red.planetarena.org/sv_downloadurl")
+
+// Set this to false to test a local news file
+#define DOWNLOADNEWS true
+// old news file with only entirely white or entirely yellow lines with + at the start
+// #define NEWSFILE "newsfeed.db"
+// new news file that supports color codes as well as entirely yellow lines with + at the start
+#define NEWSFILE "aanews.db"
+#define NEWSFEED_URL (USE_ALIENARENA_ORG ? "http://invader.alienarena.org/" NEWSFILE : "http://martianbackup.com/" NEWSFILE)
+
+#define MAPPACK_URL "http://invader.alienarena.org/arena/files"
 
 /* ---- Relative path names for game data ---*/
 /*
@@ -915,6 +963,11 @@ void FS_CreatePath( char *path );
  */
 qboolean FS_FileExists( char *path );
 
+/*
+Checks if a file exists with the specified full path.
+*/
+qboolean FS_CheckFile(const char * search_path);
+
 /**
  * @brief Get the absolute path to the game directory
  *        where configuration and non-official game
